ALTER TABLE `cm_mall_organize`
  ADD COLUMN `status` CHAR(2) NULL   COMMENT '状态:1已上线,2已下线' AFTER `mobile`;

CREATE TABLE `cm_organize_buyer`(
  `id` INT NOT NULL AUTO_INCREMENT,
  `organizeId` INT COMMENT '组织id',
  `name` VARCHAR(50) COMMENT '采购员名称',
  `mobile` VARCHAR(20) COMMENT '手机号',
  `invitationCode` VARCHAR(20) COMMENT '邀请码',
  `status` CHAR(1) COMMENT '1未绑定，2已绑定',
  `nickName` VARCHAR(32) COMMENT '微信昵称',
  `openid` VARCHAR(32) COMMENT '小程序openid',
  `addTime` DATETIME COMMENT '添加时间',
  `invitationCodeTime` DATETIME COMMENT '邀请码有效截止时间',
  `bindTime` DATETIME COMMENT '绑定时间',
  `updateTime` DATETIME COMMENT '更新时间',
  `delFlag` CHAR(1) COMMENT '0 有效 其它无效',
  PRIMARY KEY (`id`)
) CHARSET=utf8mb4
COMMENT='组织采购人员表';
-- 组织商品表
CREATE TABLE `cm_organize_product` (
    `id` INT NOT NULL AUTO_INCREMENT,
    `organizeId` INT NULL COMMENT '组织Id',
    `productId` INT NULL COMMENT '商品Id',
    `ladderPriceFlag` INT NULL DEFAULT 0 COMMENT '启用阶梯价格标识 0否 1是',
    `price` DECIMAL(11,2) NULL COMMENT '机构价',
    `includedTax` INT NULL COMMENT '是否含税   0不含税，1含税，2未知',
    `invoiceType` INT NULL COMMENT '发票类型(基于是否含税基础)   1增值税专用发票，2增值税普通发票, 3不能开票',
    `clubTaxPoint` DECIMAL(11,2) NULL DEFAULT 0 COMMENT '机构税率 :增值税默认13%，普通票6%取值范围[0-100]',
    `shopTaxPoint` DECIMAL(11,2) NULL DEFAULT 0 COMMENT '供应商税率:增值专用发票默认13%，增值税普通发票6%取值范围[0-100]',
    `minBuyNumber` INT NULL COMMENT '最小起订量',
    `costType` INT NULL COMMENT '成本价类型：1固定成本 2比例成本',
    `costPrice` DECIMAL(11,2) NULL DEFAULT 0 COMMENT '成本价',
    `costProportional` DECIMAL(11,2) NULL DEFAULT 0 COMMENT '比例成本百分比',
    `status` INT NULL DEFAULT 1 COMMENT '商品状态：0已下架，1已上架',
    `addTime` DATETIME NULL COMMENT '添加时间',
    `delFlag` INT NULL DEFAULT 0 COMMENT '删除标识：0未删除，1已删除',
PRIMARY KEY (`id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_bin
COMMENT = '采美组织商品表';

-- 组织商品阶梯价格表
CREATE TABLE `caimei`.`organize_product_ladder_price` (
      `id` INT NOT NULL AUTO_INCREMENT,
      `productId` INT NULL COMMENT '组织商品Id',
      `ladderNum` INT NULL COMMENT '第几阶梯',
      `buyNum` INT NULL COMMENT '购买数量',
      `buyPrice` DECIMAL(11,2) NULL COMMENT '购买价格',
PRIMARY KEY (`id`))
ENGINE = InnoDB
DEFAULT CHARACTER SET = utf8
COLLATE = utf8_bin
COMMENT = '组织商品阶梯价格表';


-- 新建 cm_organize_promotions 组织促销活动表
drop table `cm_organize_promotions` ;
create table `cm_organize_promotions` (
                                          `id` int(11) not null auto_increment,
                                          `organizeId` INT NULL COMMENT '组织Id',
                                          `name` varchar(8) default null comment '促销名称',
                                          `description` varchar(50) default null comment '促销描述',
                                          `type` CHAR(1) default null comment '分类: 1单品促销，2凑单促销，3店铺促销',
                                          `mode` CHAR(1) default null comment '促销方式：1优惠，2满减，3满赠',
                                          `touchPrice` decimal(10,2) default null comment '优惠价/满减/满赠的设定价格（如满999赠商品）',
                                          `reducedPrice` decimal(10,2) default null comment '减免价格',
                                          `beginTime` datetime default null comment '开始时间',
                                          `endTime` datetime default null comment '结束时间',
                                          `status` CHAR(1) default null comment '时效：1永久，2区间过期，其它无效',
                                          `delFlag` CHAR(1) default null COMMENT '0正常，1已关闭，2已删除',
                                          `addTime` datetime default null comment '添加时间',
                                          `updateTime` datetime default null comment '修改时间',
                                          primary key (`id`)
) engine=innodb default charset=utf8mb4 comment='组织促销活动表';
-- 新建 cm_organize_promotions_product 组织促销活动_组织商品_关系表
create table `cm_organize_promotions_product` (
                                                  `id` int(11) not null auto_increment,
                                                  `promotionsId` int(11) not null comment '促销活动id',
                                                  `supplierId` int(11) default null comment '店铺id(店铺促销时供应商ID)',
                                                  `productId` int(11) default null comment '组织商品id',
                                                  `addTime` datetime default null comment '添加时间',
                                                  `updateTime` datetime default null comment '修改时间',
                                                  primary key (`id`)
) engine=innodb auto_increment=208 default charset=utf8mb4 comment='促销活动_商品_关系表';
-- 新建 cm_organize_promotions_product 组织促销活动_组织赠品表
create table `cm_organize_promotions_gift` (
                                               `id` int(11) not null auto_increment,
                                               `productId` int(11) not null comment '组织赠品商品id',
                                               `number` int(11) not null default 1 comment '赠品数量',
                                               `promotionsId` int(11) not null comment '促销活动id',
                                               `addTime` datetime default null comment '添加时间',
                                               `updateTime` datetime default null comment '修改时间',
                                               primary key (`id`)
) engine=innodb auto_increment=208 default charset=utf8mb4 comment='促销活动_赠品表';
-- 新建 cm_organize_promotions_order 组织促销活动_订单_关系表
create table `cm_organize_promotions_order` (
                                                `id` int(11) not null auto_increment,
                                                `orderId` int(11) not null comment '主订单id',
                                                `promotionsId` int(11) not null comment '促销活动id',
                                                `name` varchar(8) not null comment '促销名称',
                                                `description` varchar(50) default null comment '促销描述',
                                                `type` CHAR(1) default null comment '分类: 1单品促销，2凑单促销，3店铺促销',
                                                `mode` CHAR(1) default null comment '促销方式：1优惠，2满减，3满赠',
                                                `touchPrice` decimal(10,2) default null comment '优惠价/满减/满赠的设定价格（如满999赠商品）',
                                                `reducedPrice` decimal(10,2) default null comment '减免价格',
                                                `status` CHAR(1) default null comment '时效：1永久，2区间过期，其它无效',
                                                `beginTime` datetime default null comment '活动开始时间',
                                                `endTime` datetime default null comment '活动结束时间',
                                                primary key (`id`)
) engine=innodb default charset=utf8mb4 comment='订单组织促销记录表';



ALTER TABLE `cm_mall_cart`
  CHANGE `productID` `productID` INT NOT NULL   COMMENT '关联cm_organize_product的ID';

-- 直播添加开始时间和结束时间
ALTER TABLE `new_page_live`
    ADD COLUMN `startTime` DATETIME NULL COMMENT '开始时间' AFTER `createTime`,
    ADD COLUMN `endTime` DATETIME NULL COMMENT '结束时间' AFTER `startTime`;